@@ -1,5 +1,5 @@
 from .response import JsonResponse, make_json_response
 from .decorators import jsonapi
 from .testing import FlaskJsonClient
-from .formatting import JSONEncoder, JsonSerializableBase
+from .formatting import DynamicJSONEncoder, JsonSerializableBase
 from .views import MethodView, RestfulView, methodview
